@@ -5,28 +5,28 @@ EnvironmentHelper.update("URL_VARIANT", RandomHelper.integer(minimum=0, maximum=
 log.debug(log.debug, f'variant: {EnvironmentHelper.get("URL_VARIANT")}')
 
 from python_helper import TestHelper
-# TestHelper.run(__file__)
-TestHelper.run(
-    __file__,
-    runOnly = [
-        'SerializerTest.getClassRole',
-        'SerializerTest.importResource',
-        'SerializerTest.convertFromObjectToObject',
-        'SerializerTest.convertFromObjectToObject_whenTargetClassIsList',
-        'SerializerTest.isModelTest',
-        'SerializerTest.isJsonifyable',
-        'SerializerTest.jsonifyIt',
-        'SerializerTest.fromDtoToModel',
-        'SerializerTest.fromModelToDto',
-        'SerializerTest.convertFromJsonToObject_whenThereAreEnums',
-        'SerializerTest.convertFromObjectToObject_weirdIdList',
-        'SerializerTest.convertFromJsonToObject_nativeClassAtributeList',
-        'SerializerTest.convertFromJsonToObject_listSpecialCase_whenNotFound',
-        'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundButInvalid',
-        'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundAndValid',
-        'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundAndValidKeepingDataType'
-    ]
-)
+TestHelper.run(__file__)
+# TestHelper.run(
+#     __file__,
+#     runOnly = [
+#         'SerializerTest.getClassRole',
+#         'SerializerTest.importResource',
+#         'SerializerTest.convertFromObjectToObject',
+#         'SerializerTest.convertFromObjectToObject_whenTargetClassIsList',
+#         'SerializerTest.isModelTest',
+#         'SerializerTest.isJsonifyable',
+#         'SerializerTest.jsonifyIt',
+#         'SerializerTest.fromDtoToModel',
+#         'SerializerTest.fromModelToDto',
+#         'SerializerTest.convertFromJsonToObject_whenThereAreEnums',
+#         'SerializerTest.convertFromObjectToObject_weirdIdList',
+#         'SerializerTest.convertFromJsonToObject_nativeClassAtributeList',
+#         'SerializerTest.convertFromJsonToObject_listSpecialCase_whenNotFound',
+#         'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundButInvalid',
+#         'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundAndValid',
+#         'SerializerTest.convertFromJsonToObject_listSpecialCase_whenFoundAndValidKeepingDataType'
+#     ]
+# )
 # TestHelper.run(
 #     __file__,
 #     runOnly = [
@@ -35,21 +35,21 @@ TestHelper.run(
 #         'SecurityManagerTest.securityManager_worksProperly'
 #     ]
 # )
-TestHelper.run(
-    __file__,
-    # times=10,
-    runOnly = [
-        'TestApiTest.appRun_whenEnvironmentIsPrd_withSuccess',
-        # 'TestApiTest.appRun_whenEnvironmentIsLocalFromDevConfig_withSuccess',
-        # 'TestApiTest.appRun_whenEnvironmentIsLocalFromLocalConfig_withSuccess',
-        # 'TestApiTest.pythonRun_securityManager',
-        # # 'TestApiTest.pythonRun_apiKeyManager',
-        # # 'TestApiTest.pythonRun_sessionManager',
-        # 'TestApiTest.testing_headersAndParams',
-        # # ,
-        # 'TestApiTest.testing_Client'
-    ]
-)
+# TestHelper.run(
+#     __file__,
+#     # times=10,
+#     runOnly = [
+#         'TestApiTest.appRun_whenEnvironmentIsPrd_withSuccess',
+#         # 'TestApiTest.appRun_whenEnvironmentIsLocalFromDevConfig_withSuccess',
+#         # 'TestApiTest.appRun_whenEnvironmentIsLocalFromLocalConfig_withSuccess',
+#         # 'TestApiTest.pythonRun_securityManager',
+#         # # 'TestApiTest.pythonRun_apiKeyManager',
+#         # # 'TestApiTest.pythonRun_sessionManager',
+#         # 'TestApiTest.testing_headersAndParams',
+#         # # ,
+#         # 'TestApiTest.testing_Client'
+#     ]
+# )
 # TestHelper.run(
 #     __file__,
 #     runOnly = [
@@ -64,6 +64,8 @@ TestHelper.run(
 # )
 # TestHelper.run(
 #     __file__,
+#     # logStatus = True,
+#     # wrapperStatus = True,
 #     runOnly = [
 #         'EnumAnnotationTest.enum_withSuccess',
 #         'EnumAnnotationTest.otherEnum_withSuccess',
